==> sveltefirets-0.0.20.tgz: package/client/firestore.js <==
/* eslint-disable @typescript-eslint/no-unused-vars */
// Inspired by https://fireship.io/lessons/firestore-advanced-usage-angularfire/
import { collection, doc, getDocs, getDoc, query, addDoc, setDoc, deleteDoc, updateDoc, serverTimestamp, } from 'firebase/firestore';
import { getDb } from './init';
import { getUid } from './uid';
export function colRef(ref) {
    const db = getDb();
    return typeof ref === 'string' ? collection(db, ref) : ref;
}
export function docRef(ref) {
    if (typeof ref === 'string') {
        const pathParts = ref.split('/');
        const documentId = pathParts.pop();
        const collectionString = pathParts.join('/');
        return doc(colRef(collectionString), documentId);
    }
    else {
        return ref;
    }
}
export async function getCollection(path, queryConstraints = []) {
    const ref = typeof path === 'string' ? colRef(path) : path;
    const q = query(ref, ...queryConstraints);
    const collectionSnap = await getDocs(q);
    return collectionSnap.docs.map((docSnap) => ({
        ...docSnap.data(),
        id: docSnap.id,
    }));
}
export async function getDocument(ref) {
    const docSnap = await getDoc(docRef(ref));
    return docSnap.exists() ? { ...docSnap.data(), id: docSnap.id } : null;
}
export function add(ref, data, opts = {}) {
    return addDoc(colRef(ref), {
        ...data,
        [opts.abbreviate ? 'ca' : 'createdAt']: serverTimestamp(),
        [opts.abbreviate ? 'cb' : 'createdBy']: getUid(),
        [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
        [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
    });
}
export async function set(ref, data, opts = {}) {
    const snap = await getDocument(ref);
    return await (snap
        ? update(ref, data)
        : setDoc(docRef(ref), {
            ...data,
            [opts.abbreviate ? 'ca' : 'createdAt']: serverTimestamp(),
            [opts.abbreviate ? 'cb' : 'createdBy']: getUid(),
            [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
            [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
        }, { merge: opts.merge }));
} // could split apart into set and upsert if desired, https://stackoverflow.com/questions/46597327/difference-between-set-with-merge-true-and-update
export async function update(ref, data, opts = {}) {
    // @ts-ignore
    return updateDoc(docRef(ref), {
        ...data,
        [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
        [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
    });
}
export function deleteDocument(ref) {
    return deleteDoc(docRef(ref));
}
export async function docExists(ref) {
    return (await getDoc(docRef(ref))).exists();
}

==> sveltefirets-0.0.25.tgz: package/client/firestore.js <==
/* eslint-disable @typescript-eslint/no-unused-vars */
// Inspired by https://fireship.io/lessons/firestore-advanced-usage-angularfire/
import { collection, doc, getDocs, getDoc, query, addDoc, setDoc, deleteDoc, updateDoc, serverTimestamp, } from 'firebase/firestore';
import { getDb } from './init';
import { getUid } from './uid';
export function colRef(ref) {
    const db = getDb();
    return typeof ref === 'string' ? collection(db, ref) : ref;
}
export function docRef(ref) {
    if (typeof ref === 'string') {
        const pathParts = ref.split('/');
        const documentId = pathParts.pop();
        const collectionString = pathParts.join('/');
        return doc(colRef(collectionString), documentId);
    }
    else {
        return ref;
    }
}
export async function getCollection(path, queryConstraints = []) {
    const ref = typeof path === 'string' ? colRef(path) : path;
    const q = query(ref, ...queryConstraints);
    const collectionSnap = await getDocs(q);
    return collectionSnap.docs.map((docSnap) => ({
        ...docSnap.data(),
        id: docSnap.id,
    }));
}
export async function getDocument(ref) {
    const docSnap = await getDoc(docRef(ref));
    return docSnap.exists() ? { ...docSnap.data(), id: docSnap.id } : null;
}
export function add(ref, data, opts = {}) {
    data[opts.abbreviate ? 'ca' : 'createdAt'] = serverTimestamp();
    data[opts.abbreviate ? 'cb' : 'createdBy'] = getUid();
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return addDoc(colRef(ref), data);
}
export async function set(ref, data, opts = {}) {
    const snap = await getDocument(ref);
    if (snap) {
        return await update(ref, data);
    }
    data[opts.abbreviate ? 'ca' : 'createdAt'] = serverTimestamp();
    data[opts.abbreviate ? 'cb' : 'createdBy'] = getUid();
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return await setDoc(docRef(ref), data, { merge: opts.merge });
} // could split apart into set and upsert if desired, https://stackoverflow.com/questions/46597327/difference-between-set-with-merge-true-and-update
export async function update(ref, data, opts = {}) {
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return updateDoc(docRef(ref), data);
}
export function deleteDocument(ref) {
    return deleteDoc(docRef(ref));
}
export async function docExists(ref) {
    return (await getDoc(docRef(ref))).exists();
}
